.. _explanation:

#############
 Explanation
#############

In here you will find information related to icclim. For more technical
knowledge, see :ref:`references`.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   climate_indices
   xclim_and_icclim
   4.2.x_installation
